/* TileRasterCache, a library to download tiles from several sources.
 *
 * Copyright (C) 2010 Prodevelop SL.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *  
 *   Prodevelop Integracin de Tecnologas SL
 *   Plaza don Juan de Vilarrasa , 14-5
 *   46000 Valencia
 *   Spain
 *
 *   +34 963 510 612
 *   +34 963 510 968
 *   gis@prodevelop.es
 *   http://www.prodevelop.es
 *   
 *   author: Alberto Romeu Carrasco (aromeu@prodevelop.es)
 */

package es.prodevelop.tilecache.generator.impl;

import es.prodevelop.tilecache.generator.IBufferStrategy;

/**
 * A Buffer strategy that calculates the minimum number of tiles around the
 * center tile in the map to fit the size of the map
 * 
 * @author aromeu
 * 
 */
public class FitScreenBufferStrategy implements IBufferStrategy {

	public int calculateTileUpperBound(int zoomLevel) {
		return (int) Math.pow(2, zoomLevel + 1) + 1;
	}

	public int[] calculateBufferAroundCenterTile(int mapWidthPx,
			int mapHeightPx, int tileSizePx, int centerMapTileScreenLeft,
			int centerMapTileScreenRight, int centerMapTileScreenTop,
			int centerMapTileScreenBottom) {
		int[] res = new int[4];
		res[0] = (int) Math.ceil((float) centerMapTileScreenLeft / tileSizePx);
		res[1] = (int) Math
				.ceil((float) (mapWidthPx - centerMapTileScreenRight)
						/ tileSizePx);
		res[2] = (int) Math.ceil((float) centerMapTileScreenTop / tileSizePx);
		res[3] = (int) Math
				.ceil((float) (mapHeightPx - centerMapTileScreenBottom)
						/ tileSizePx);

		return res;
	}
}
