package es.prodevelop.tilecache.provider.event;

import es.prodevelop.gvsig.mini.common.IEvent;
import es.prodevelop.gvsig.mini.common.impl.Tile;

/**
 * A container of some interesting information when a tile has been retrieved by
 * the TileProvider
 * 
 * @author aromeu
 * 
 */
public class TileEvent implements IEvent {

	public static final int TILE_LEVEL_MEMORY_CACHE = 0;
	public static final int TILE_LEVEL_FILE_SYSTEM = 1;
	public static final int TILE_LEVEL_SERVER = 2;

	private Tile mTile;
	private String mPath;
	private int mMode;
	private String mStrategyName;
	private int mTileLevel;

	/**
	 * The constructor
	 * 
	 * @param aTile
	 *            The tile retrieved by the TileProvider
	 * @param aPath
	 *            The path of the tile returned by the ITileFileSystemProvider
	 * @param aMode
	 *            The mode of the TileProvider that retrieved the tile
	 * @param aStrategyName
	 *            The strategy used to get the tile
	 * @param aTileLevel
	 *            the cache level where the tile has been retrieved. one of:
	 *            TILE_LEVEL_MEMORY_CACHE, TILE_LEVEL_FILE_SYSTEM,
	 *            TILE_LEVEL_SERVER
	 */
	public TileEvent(Tile aTile, String aPath, int aMode, String aStrategyName,
			int aTileLevel) {
		this.mTile = aTile;
		this.mPath = aPath;
		this.mMode = aMode;
		this.mStrategyName = aStrategyName;
	}

	/**
	 * @return the Tile
	 */
	public Tile getTile() {
		return mTile;
	}

	/**
	 * @return the Path
	 */
	public String getPath() {
		return mPath;
	}

	/**
	 * @return the Mode
	 */
	public int getMode() {
		return mMode;
	}

	/**
	 * @return the StrategyName
	 */
	public String getStrategyName() {
		return mStrategyName;
	}

	/**
	 * @return the TileLevel
	 */
	public int getTileLevel() {
		return mTileLevel;
	}

	public String getMessage() {
		StringBuffer message = new StringBuffer();
		if (mTile != null) {
			if (mTile.mURL != null)
				message.append("URL: ").append(mTile.mURL).append("-");
		}

		if (mPath != null)
			message.append("PATH: ").append(mPath).append("-");

		message.append("MODE: ").append(mMode).append("-");

		if (mStrategyName != null)
			message.append("STRATEGY: ").append(mStrategyName).append("-");

		message.append("TILE LEVEL: ").append(mTileLevel);

		return message.toString();
	}
}
