/* TileRasterCache, a library to download tiles from several sources.
 *
 * Copyright (C) 2010 Prodevelop SL.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *  
 *   Prodevelop Integracin de Tecnologas SL
 *   Plaza don Juan de Vilarrasa , 14-5
 *   46000 Valencia
 *   Spain
 *
 *   +34 963 510 612
 *   +34 963 510 968
 *   gis@prodevelop.es
 *   http://www.prodevelop.es
 *   
 *   author: Alberto Romeu Carrasco (aromeu@prodevelop.es)
 */

package es.prodevelop.tilecache.provider.filesystem.strategy.impl;

import java.util.ArrayList;

import es.prodevelop.tilecache.provider.filesystem.strategy.ITileFileSystemStrategy;

/**
 * A manager to register ITileFileSystemStrategy implementations. 
 * @author aromeu
 *
 */
public class FileSystemStrategyManager {
	
	private static FileSystemStrategyManager manager;
	private ArrayList<ITileFileSystemStrategy> strategies = new ArrayList<ITileFileSystemStrategy>();
	
	/**
	 * A singleton
	 * @return
	 */
	public static FileSystemStrategyManager getInstance() {
		if (manager == null) {
			manager = new FileSystemStrategyManager();
		}
		return manager;
	}
	
	/**
	 * Registers a new ITileFileSystemStrategy implementation
	 * @param fs
	 */
	public void registerFileSystemStrategy(ITileFileSystemStrategy fs) {
		strategies.add(fs);
	}

	/**
	 * 
	 * @return The ITileFileSystemStrategy registered
	 */
	public ArrayList<ITileFileSystemStrategy> getStrategies() {
		return strategies;
	}
	
	/**
	 * Returns a ITileFileSystemStrategy given its name
	 * @param name
	 * @return
	 */
	public ITileFileSystemStrategy getStrategyByName(String name) {
		for (ITileFileSystemStrategy fs : strategies) {
			if (fs.getName().compareTo(name) == 0) {
				return fs;
			}
		}
		return null;
	}
}
