/* TileRasterCache, a library to download tiles from several sources.
 *
 * Copyright (C) 2010 Prodevelop SL.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *  
 *   Prodevelop Integraci�n de Tecnolog�as SL
 *   Plaza don Juan de Vilarrasa , 14-5
 *   46000 Valencia
 *   Spain
 *
 *   +34 963 510 612
 *   +34 963 510 968
 *   gis@prodevelop.es
 *   http://www.prodevelop.es
 *   
 *   author: Alberto Romeu Carrasco (aromeu@prodevelop.es)
 */

package es.prodevelop.tilecache.provider.filesystem.strategy.impl;


/**
 * This IFileSystemStrategy creates a directory for each zoom level of a layer.
 * Inside the directory of a zoom level, creates a directory for each X row and
 * inside the directory of an X row stores a file with the Y row, so
 * OSM/0/0/0.tile represents the tile http://osm/0/0/0.png
 * 
 * This strategy is the most spread for mobile map viewers (although is not the most efficient)
 * @author aromeu
 *
 */
public class FlatXFileSystemStrategy extends DefaultFileSystemStrategy {
	
	public FlatXFileSystemStrategy() {
		super();
	}

	public FlatXFileSystemStrategy(String tileNameSuffix) {
		super(tileNameSuffix);		
	}

	public String getRelativeToLayerDirTilePath(int[] tile, int zoomLevel) {
		return new StringBuffer().append(zoomLevel).append("/").append(tile[1])
				.append("/").append(tile[0]).toString();
	}
	
	public String getLayerNameSuffix() {
		return "_flatx";
	}	

	public String getName() {
		return FLATX;
	}	
}
