/* TileRasterCache, a library to download tiles from several sources.
 *
 * Copyright (C) 2010 Prodevelop SL.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *  
 *   Prodevelop Integraci�n de Tecnolog�as SL
 *   Plaza don Juan de Vilarrasa , 14-5
 *   46000 Valencia
 *   Spain
 *
 *   +34 963 510 612
 *   +34 963 510 968
 *   gis@prodevelop.es
 *   http://www.prodevelop.es
 *   
 *   author: Alberto Romeu Carrasco (aromeu@prodevelop.es)
 */

package es.prodevelop.tilecache.provider.filesystem.strategy.impl;

import es.prodevelop.gvsig.mini.projection.TileConversor;
import es.prodevelop.tilecache.provider.filesystem.strategy.ITileFileSystemStrategy;

/**
 * This strategy applies a Quadkey to the downloaded tiles.
 * 
 * OSM/0/a.tile represents the tile http://osm/0/0/0.png
 * 
 * Each tile is converted to its Quadkey notation and transported to the file
 * system. With this strategy each directory has at most 5 files (4 directories
 * and a file) so is very efficient for mobile devices.
 * 
 * This strategy was used at first by gvSIG Mini for Java phones as we see that
 * behaved better than any other. The problem is that is not very used for any
 * other mobile map viewer so is not interoperable at all. Another problem is
 * that is difficult for example take from the file system all the tiles from a
 * zoom level, as they are spread on subdirectories... so swap tiles from
 * different layers into the same layer directory is very difficult
 * 
 * @author aromeu
 * 
 */
public class QuadKeyFileSystemStrategy extends DefaultFileSystemStrategy {

	private final static String DEFAULT_TILE_NAME = "a";

	public QuadKeyFileSystemStrategy() {
		super();
	}

	public QuadKeyFileSystemStrategy(String tileNameSuffix) {
		super(tileNameSuffix);
	}

	public String getRelativeToLayerDirTilePath(int[] tile, int zoomLevel) {
		final StringBuffer quad = TileConversor.tileXYToQuadKey(tile[1],
				tile[0], zoomLevel + 1);
		final String quadDir = TileConversor.quadKeyToDirectory(quad)
				.toString();
		return quadDir;
	}

	public String getTileNameSuffix() {
		String suffix = super.getTileNameSuffix();
		return DEFAULT_TILE_NAME + suffix;
	}

	public String getLayerNameSuffix() {
		return "";
	}

	public String getName() {
		return QUADKEY;
	}
}
